/*
Program 5: proccmf3.sas
*/


* proccmf3.sas *****;
libname c "/economic/lbd/microdata";
libname d "/rdcprojects/ch/ch01440/data";
** based on cmf;
** emp is total employment;
** emp_va is value-added based employment;
** emp_tfpq is employment based on tfpq (only tauy);

data one (keep=year firmid lbdnum emp va dind2 dind3 yl yk wage);
  set d.cmffinal;
  lbdnum = newid;
  if year = 1977 or year = 1982 or year = 1987 or year = 1992 or year = 1997 or year = 2002 or year = 2007 or year = 2012;

  * dind2 is two digit sic or 3 digit naics *****;
  * dind2 = floor(sic/100);
   dind2 = sic;
  if sic = . then dind2 = sic2;
*  if sic = . then dind2 = floor(sic2/100);
  dind3 = dind2; *use for 2002;
*  if year > 2001 then dind2 = floor(naics/1000);
  if year > 2001 then dind2 = naics;
  ** dind2 is sic until 2001;
  ** dind2 is naics after 2001;
  ** dind3 is sic to use for changes from 1997 to 2002;

  if dind2 = . then delete;
  if firmid = . then delete;
  emp = te;
  if emp <= 0 then delete;
  if emp = . then delete;
  if year = . then delete;

  k = (tab + tae)/2;
  if year <= 1992 then k = (bab + bae + mab + mae)/2;

  yl = .;
  yk = .;
  if va <= 0 then delete;
  if va = . then delete;
  yl = va/(sw +lc);
  yk = va/k;
  if yk <= 0 then yk = .;
  if yl = . then delete;
  if yl = 0 then delete;
  wage = sw + lc;
  if wage <= 0 then wage = .;
run;

proc sort data=one; by year dind2;
run;

proc rank data=one out=one groups=99;
  by year dind2;
  var yk yl;
  ranks rankyk rankyl;
run;

data one;
  set one;
  if rankyk = 0 or rankyk = 98 then yk = .;
  if rankyl = 0 or rankyl = 98 then yl = .;
  if yl = . then delete;
  if yk = . then delete;
run;
** outliers trimmed;

** firmid *** to identify entry and exit ********************************************;
data oneid (keep=year firmid emp);
  set one;
  if emp = . then delete;
run;

proc sort data=oneid; by year firmid;
run;

proc means noprint data=oneid;
  var emp;
  by year firmid;
output out=oneid sum=;
run;

data oneidforward (drop=emp);
  set oneid;
  year = year - 5;
  forward = 1;
run;

proc sort data=oneidforward;
  by year firmid;
run;

data oneid;
  set oneid;
  inc = 1;
run;

proc sort data=oneid;
  by year firmid;
run;

data d.onecmfvaid (keep=year firmid new exit);
  merge oneid oneidforward;
  by year firmid;
  if year = 1977 or year = 1982 or year = 1987 or year = 1992 or year = 1997 or year = 2002 or year = 2007;
  exit = 0;
  new = 0;
  if forward = 1 and inc = . then new = 1;
  if inc = 1 and forward = . then exit = 1;
run;

** end of firmid with entry and exit dummy *****************************************************;

data exit (keep=year firmid exit);
  set d.onecmfvaid;
  if exit = 1;
run;

data new (keep=year firmid new);
  set d.onecmfvaid;
  if new = 1;
  year = year + 5;
run;

** aggregate employment by year **********************;
proc sort data=one; by year dind2;
run;

proc means noprint data=one;
  var emp;
  by year;
output out=empyear sum(emp)=empyear;
run;

data empyearforward (keep=year empyearforward);
  set empyear;
  year = year - 5;
  empyearforward = empyear;
run;

data empyear (keep=year dempyear empyear empyearforward);
  merge empyear empyearforward; by year;
  dempyear = empyearforward - empyear;
  if dempyear = . then delete;
run;

* dempyear is change in employment by year, empyear is level of employment by year;
* empyearforward is total employmenat by year five years later;

** now aggregate employment, wage bill, and va by industry ************************;
proc means data=one noprint;
  var emp va wage;
  by year dind2;
output out=empind sum(emp va wage)=empind vaind wageind;

** merge with master dataset *********************************************************************************************;
data one;
  merge one empind;
  by year dind2;
  vashare = va/vaind;
  labshare = wageind/((3/4)*vaind);
  if labshare >= 1 then labshare = .;
  if labshare <= 0 then labshare = .;
  invyl = 1/yl;
  invyk = 1/yk;
  if labshare = . then delete;
run;
** need vashare of each plant and laborshare of each industry to take weighted average ***********************************;

** weighted average of yl and yk ***************************;
proc means data=one noprint;
  var invyl invyk;
  weight vashare;
  by year dind2;
output out=yl mean(invyl invyk)=invylmean invykmean;

** merge back to one 
*****************************************************************************************************************************************************************************;
data one;
  merge one yl;
  by year dind2;
  empva = vashare*empind;  * output based employment;
  tfpqadj1 = va*yl**3;  *tfpq based employment, only tauy;
  tfpqadj2 = va*((yl)**labshare*(yk)**(1-labshare))**3;  *tfpq based employment, tauy and tauk;
run;

proc means noprint data=one;
  by year dind2;
  var tfpqadj1 tfpqadj2;
  output out=adj sum(tfpqadj1 tfpqadj2)=adj1 adj2;
run;


data one;
  merge one adj; by year dind2;
  emptfpq = empind*(tfpqadj1/adj1);
  emptfpqall = empind*(tfpqadj2/adj2);
*  lemp = log(emp);  
*  lempva = log(empva);  
*  lemptfpq = log(emptfpq); 
run;
** emp is original employment, emp_va is employment based on value-added, emp_tfpq is employment based on tfpq only allowing for tauy, emp_tfpqall is tfpq based on tauy and tauk 
*********************************************************************************************************;

** at this point dataset one is still the cross-section **********************************************************;
proc sort data=one; by year firmid;
run;

** sum to firm level *********************;
proc means noprint data=one;
  by year firmid;
  var emptfpq emptfpqall emp empva;
output out=onecross sum(emptfpq emptfpqall emp empva)=;
run;

data onecross;
  merge onecross new exit;
  by year firmid;
  if new = . then new = 0;
  if exit = . then exit = 0;
  if emp = . then delete;
  if year = 1977 then delete;
  if year = 2012 then delete;
  exit = exit/5;
run;

proc means noprint data=onecross;
  by year;
  var emptfpq emptfpqall emp empva;
output out=onemean mean(emptfpq emptfpqall emp empva)=emptfpq_m emptfpqall_m emp_m empva_m;
run;

data onecross;
  merge onecross onemean; by year;
  bigtfpq = 0;
  bigtfpqall = 0;
  bigemp = 0;
  bigva = 0;
  if emptfpq > emptfpq_m then bigtfpq = 1;
  if emptfpqall > emptfpqall_m then bigtfpqall = 1;
  if empva > empva_m then bigva = 1;
  if emp > emp_m then bigemp = 1;
run;

proc sort data=onecross; by year new;
run;

proc means noprint data=onecross;
  var emptfpq emptfpqall empva emp;
  by year new;
output out=oneyoung mean=;
run;

* proc print data=oneyoung;
run;

proc sort data=onecross; by year bigemp;
run;

proc means data=onecross noprint;
  by year bigemp;
  var exit;
output out=exit mean=;

* proc print data=exit;

proc sort data=onecross; by year bigva;
run;

proc means data=onecross noprint;
  by year bigva;
  var exit;
* output out=exit mean=;

proc print data=exit;

proc sort data=onecross; by year bigtfpq;
run;

proc means data=onecross noprint;
  by year bigtfpq;
  var exit;
output out=exit mean=;

* proc print data=exit;

proc sort data=onecross; by year bigtfpqall;
run;

proc means data=onecross noprint;
  by year bigtfpqall;
  var exit;
output out=exit mean=;

* proc print data=exit;

** now for 2002 *************************************************************************;
proc sort data=one; by year dind3;
run;

proc means data=one noprint;
  var emp;
  by year dind3;
output out=empind2002 sum=empindforward;
run;

data empind2002 (keep=year dind2 empindforward);
  set empind2002;
  if year = 2002;
  dind2 = dind3;
  year = year - 5;
run;

data empindforward (keep=year dind2 empindforward);
  set empind;
  if year = 2002 then delete;
  year = year - 5;
  empindforward = empind;
run;

data empindforward;
  set empindforward empind2002;
run;
** total employment by industry in 2002 is now based on dind3 (sic instead of naics) **************;

** total change in employment by industry *********************************************************;
proc sort data=empindforward;
  by year dind2;
run;

data empind (keep=year dind2 dempind empind);
  merge empind empindforward;
  by year dind2;
  dempind = empindforward - empind;
  if dempind = . then delete;
run;

data empind;
  merge empind empyear; by year;
  if empyear = . then delete;
  if year = 1977 or year = 1982 or year = 1987 or year = 1992 or year = 1997 or year = 2002 or year = 2007;
run;

* dempyear is change in employment by year, empyear is level of employment by year, empind is level of employment by industry;
* empyearforward is total employmenat by year five years later;
* dempdind is change in total employment by year and industry;
**** end total employment by industry and year ********************************************************************************;

** now change in employment by PLANT ***********************************************************;
proc sort data=one;
  by year lbdnum;
run;

data oneforward (keep=year dind4 lbdnum empforward empvaforward emptfpqforward emptfpqallforward firmidforward);
  set one;
  year = year - 5;
  empforward = emp;
  empvaforward = empva;
  emptfpqforward = emptfpq;
  emptfpqallforward = emptfpqall;
  firmidforward = firmid;
  if year = 1997 then dind2 = dind3;  * two digit sic for new plants in 2003;
  dind4 = dind2;
  if year = 1977 or year = 1982 or year = 1987 or year = 1992 or year = 1997 or year = 2002 or year = 2007;
run;

data one;
  merge one oneforward; by year lbdnum;  * match by plant id;
  if year = 1977 or year = 1982 or year = 1987 or year = 1992 or year = 1997 or year = 2002 or year = 2007;

  demp = empforward - emp;  * surviving plants ;
  dempva = empvaforward - empva;
  demptfpq = emptfpqforward - emptfpq;
  demptfpqall = emptfpqallforward - emptfpqall;

  newplant = 0;
  exitplant = 0;
  changeowner  = 0;
  emp2 = emp;  * use this to calculate share of total employment by plant;

  ** surviving establishments that change ownership ******;
  if empforward ~= . and emp ~= . and firmid ~= firmidforward then changeowner = 1;

  ** new plants five years later;
  if emp = . then do;
      demp = empforward;
      dempva = empvaforward;
      demptfpq = emptfpqforward;
      demptfpqall = emptfpqallforward;
      emp2 = empforward;
      newplant = 1;
      firmid = firmidforward;
      dind2 = dind4;
  ** firmid of entrants is id of firm that owns the plant five years later;
  ** some of these plants will be owned by firms that exist at time t -- others will be firms that are brand new at t+1 (five years later;
  end;

  ** plants that exit five years later *********;
  if empforward = . then do;
      demp = - emp;
      dempva = - empva;
      demptfpq = - emptfpq;
      demptfpqall = - emptfpqall;
      exitplant = 1;
  * change in employment is minus employment at time t *****;
  end;

  if demp = . then delete;
run;

data oneb;
  set one;
  if changeowner = 1;
      demp = - emp;  * change in employment is minus employment at time t;
      dempva = - empva;
      demptfpq = - emptfpq;
      demptfpqall = - emptfpqall;
  exitplant = 1;
  empforward = .;
  * surviving establishments that change ownership counted as exiter -- firmid is firm that owns plant at time t;
  * these are will also be considered new plants at t+1;
run;

data onec;
  set one;
  if changeowner = 1;
      demp = empforward;
      dempva = empvaforward;
      demptfpq = emptfpqforward;
      demptfpqall = emptfpqallforward;
  firmid = firmidforward;
  emp = .;
  newplant = 1;
  exitplant = 0;
run;

data oned;
  set one;
  if changeowner = 1 then delete;
run;

data one (drop=firmidforward);
  set oned oneb onec;
  if emp = . then emp = 0;
  if empforward = . then empforward = 0;
run;  * this now has stacked dataset including new plants in t+1 and surviving plants that switched ownership;

** end of stacked dataset *****************************************************************************************;

** now total employment by industry based on emp2 *********************************************************;
proc sort data=one; by year dind2;
run;

proc means data=one noprint;
  var emp2;
  by year dind2;
output out=one2 sum=emp2ind;
run;  *total employment based on emp2;

data one (keep=year firmid demp demporig demptfpq dempva demptfpqall emp empforward empva empvaforward emptfpq emptfpqforward emptfpqall emptfpqallforward);
  merge one one2 empind; by year dind2;
  demporig = demp;
  share_plant = emp2/emp2ind;
  share_industry = empind/empyear;
  adj = share_plant*(dempind - share_industry*dempyear);
  demp = demp - adj;
  dempva = dempva - adj;
  demptfpq = demptfpq - adj;
  demptfpqall = demptfpqall - adj;
run;

** one has change in employment adjusted by industry and annual employment by plant **************************************;

** aggregate to firm level ************************************************;
proc sort data=one; by year firmid;
run;

proc means data=one noprint; by year firmid;
  var emp demp demporig demptfpq dempva demptfpqall empforward empva empvaforward emptfpq emptfpqforward emptfpqall emptfpqallforward;
  output out=two sum=;
run;

** KEY KEY KEY KEY KEY KEY KEY ************************************************************************;
** this is the data step where adjustments have to be made for different definitions of employment ****;
data two;
  merge two d.onecmfvaid; by year firmid;
  demp2 = demp;  * original demp adjusted for aggregate industry changes;
  * demp = dempva;
  * demp = demporig;
  * demp = demptfpq;
  demp = demptfpqall;
  if demp = . then delete;
  emp = emptfpqall;
  empforward = emptfpqforwardall;
  * emp = empva;
  * empforward = empvaforward;
  * emp = emptfpq;
  * empforward = emptfpqforward;
  pos = 0;
  if demp >= 0 then pos = 1;
  if demp < 0 then pos = 0;
run;
** end of adjustment *********************************************************************************;


proc sort data=two; by year;
run;

proc means data=two noprint;
  var demp2 demp;
  by year;
output out=demporig sum(demp2 demp)=sumdemp2 sumdemp;
run;

data two;
  merge two demporig; by year;
  demp = demp*(sumdemp2/sumdemp);
run;

* demp is total ADJUSTED change in employment among establishments owned by firm including entrants owned five years later;
* emp is total employment of firm at time t;
* empforward is total employment of firm at time t + 1;
* exit is indicator variable for exiting firm;
* new is indicator variable for new firm at END of period;
** end of aggregation to firm *********************************************;

data pos;
  set two;
  if pos = 1;
run;

proc means data=pos noprint;
  var demp;
  by year;
output out=jc sum(demp)=jc;

data entry;
  set pos;
  if new = 1;
run;

proc means data=entry noprint;
  var demp ;
  by year;
output out=jc_entry sum(demp)=jc_entry ;

data small;
  set pos;
  if new = 0;
  dempsh = demp/((emp + empforward)/2);
  if dempsh < 1;
run;

proc means data=small noprint;
  var demp;
  by year;
output out=jc_small sum(demp)=jc_small;

data neg;
  set two;
  if pos = 0;
run;

proc means data=neg noprint;
  var demp;
  by year;
output out=jd sum(demp)=jd;

data exit;
  set neg;
  if exit = 1;
run;

proc means data=exit noprint;
  var demp ;
  by year;
output out=jd_exit sum(demp)=jd_exit ;
run;

data jcjd (keep = year jc jcrate jc_entry jc_small jd jdrate jd_exit);
  merge jc jc_entry jc_small jd jd_exit empyear;  * empyear has total employment in the two years;
  by year;
  jcrate = jc/((empyear + empyearforward)/2);
  jc_entry = jc_entry/jc;
  jc_small = jc_small/jc;
  jdrate = jd/((empyear + empyearforward)/2);
  jd_exit = jd_exit/jd;
run;

proc print data=jcjd;  ** aggregate job creation and destruction rate ***;
  var year jc jd jcrate jdrate jc_entry jc_small jd_exit;
title1 ' JC and JD ';
run;
** end total ** adjusted ** job creation and job desruction ***********;

* end proccmf3.sas *****************************************************;



