
/*
Program 7: proclbd2_ict.sas
*/


* proclbd2_ict.sas;

* libname c "/economic/lbd/microdata";
* libname d "/rdcprojects/ch/ch01440/data";

* library c is not used in this sas file and the directory structure of raw lbd data has changed;
libname d "/projects/data";


data one (drop = twonaics onesic);
  set d.lbd;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2001 or year = 2003 or year = 2008 or year = 2013;
  twonaics=floor(naics/1000);

  * need to restrict to ICT sector;
  * can not disclose specific naics or SIC codes used;

  age = year - yearmin_firm;
  if firmid = . then delete;
  if emp <= 0 then delete;
  if emp = . then delete;
  if year = . then delete;
  dind2 = floor(sic/100);
  if year > 2001 then dind2 = floor(naics/1000);
run;

proc sort data=one; by year firmid;
run;

** aggregate to firm level ************************************************;
proc means data=one noprint; by year firmid;
  var emp age yearmin_firm yearmax_firm;
  output out=two mean(yearmin_firm yearmax_firm)= max(age)= sum(emp)=;
run;   * age is maximum age of plant within a firm;

data two;
  set two;
  exit1 = 0;
  if yearmax_firm = year then exit1 = 1;
  exit5 = 0;
  if yearmax_firm < year + 5 then exit5 = 1;
run;

** average size *************;
proc means data=two noprint;
  var emp;
  by year;
output out=empavg (keep=year empavg) mean=empavg;

proc means data=two noprint;
  var emp;
  wgt emp;
by year;
output out=wempavg (keep=year empmedian) mean=empmedian;
run;

data two;
  merge two empavg;
  by year;
  entrant = 0;
  big = 0;
  if age <= 4 then entrant = 1;
  if emp > empavg then big = 1;
  count = 1;
  lemp = log(emp);
run;
** two is dataset with firm aggregates ************************************;

proc sort data=two; by year entrant;

proc means data=two noprint; by year;
  var emp count lemp exit5;
  output out=sum mean(exit5)=exit5_all sum(emp count)=empyear totnfirm std(lemp)=sdlemp;
run;

proc means data=two noprint; by year entrant;
  var emp count lemp exit5;
  output out=entrant mean(emp exit5)=empent exit5_entrant sum(emp count)=empentsum nfirm_entrant std(lemp)=sdlemp_entrant;
run;

data entrant1 (keep = year empent empentsum nfirm_entrant sdlemp_entrant exit5_entrant);
  set entrant;
  if entrant = 1;
run;

data entrant2 (keep = year empinc);
  set entrant;
  if entrant = 0;
  empinc = empent;
run;

proc sort data=two; by year big;

proc means data=two noprint; by year big;
  var exit5;
  output out=exit mean=;
run;

data exit1 (keep = year exitbig);
  set exit;
  if big = 1;
  exitbig = exit5/5;
run;

data exit2 (keep = year exitsmall);
  set exit;
  if big = 0;
  exitsmall = exit5/5;
run;

data all;
  merge sum entrant1 entrant2 exit1 exit2 empavg wempavg; by year;
  entrantshare = empentsum/empyear;
  entrantfirmshare = nfirm_entrant/totnfirm;
  empyear = empyear/1000;
  exit5_all = exit5_all/5;
  exit5_entrant = exit5_entrant/5;
run;

data forward (keep=year empyearforward);
  set all (keep=year empyear);
  year = year - 5;
  empyearforward = empyear;
run;

data bs;
  set all (keep=year empyear);
run;

data bs (keep=year empgrowth);
  merge bs forward; by year;
  empgrowth = (log(empyearforward/empyear))/5;
  year2 = .;
  if year = 1983 or year = 1988 then year2 = 1988;
  if year = 1993 or year = 1998 then year2 = 1998;
  if year = 2003 or year = 2008 then year2 = 2008;
  if year2 = . then delete;
  year = year2;
run;

proc sort data=bs; by year;

proc means data=bs noprint;
  var empgrowth;
  by year;
output out=empgrowth mean=;

data all;
  merge all empgrowth; by year;
  if empgrowth = . then delete;
run;

proc print data=all;
  var year exit5_entrant exit5_all entrantfirmshare totnfirm entrantshare empent empinc empavg empmedian;
run;

proc print data=all;
  var year exitsmall exitbig empyear empgrowth sdlemp_entrant sdlemp;
run;

* end proclbd2_ict.sas;

