

/*
Program 12: proclbd3.sas
*/


* proclbd3.sas;

* libname c "/economic/lbd/microdata";
* libname d "/home/h/hsieh001/data";

* library c is not used in this sas file and the directory structure of raw lbd data has changed;
* The directory for library d was different from the usual ones we have. Please double check.;
libname d "/projects/data";


* change entrants to firms in year t+1 not in data in year t;
** adjust JD and JC at four digit SIC (until 2001) and six digit NAICS (after 2001);

** need to run the following program only once ***;

** crosswalk between two digit sic and naics based on 1998 and 2003 data ******;
data bs;
  set d.lbd (keep=year naics sic emp);
  if year = 1998 or year = 2003;
  * twosic = floor(sic/100);
  * twonaics = floor(naics/1000);
twosic = sic;
twonaics =naics;
if twosic = . then delete;
  if twonaics = . then delete;
run;

proc sort data=bs; by twonaics twosic;
run;

proc means data=bs noprint;
  by twonaics twosic;
  var emp;
output out=bs2 sum=empmax;
run;

proc sort data=bs2 out=bs3;
  by twonaics descending empmax;
run;

proc sort data=bs3 out=bs3 nodupkey;
  by twonaics;
run;

data d.twonaics (keep=dind2 twosic);
  set bs3;
  dind2 = twonaics;
run;

proc sort data=d.twonaics; by dind2;
run;
** end crosswalk **************************************************************;
** end of program that needs to be run once ***;

data one (keep=year firmid lbdnum emp dind2 dind3);
  set d.lbd;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2001 or year = 2003 or year = 2008 or year = 2013;
  * 1983 to 1988, 1988 to 1993, 1993 to 1998, 1998 to 2003, 2003 to 2008, 2008 to 2013;

  * dind2 is two digit sic or 3 digit naics *****;
  * dind2 = floor(sic/100);
  dind2 = sic;
  if sic = . then dind2 = sic2;
*  if sic = . then dind2 = floor(sic2/100);
  dind3 = dind2; *use for 2003;
*  if year > 2001 then dind2 = floor(naics/1000);
  if year > 2001 then dind2 = naics;

  if dind2 = . then delete;
  *** end dind2 *********************************;

  twonaics=floor(naics/1000);

  * can not disclose specific industries;
  * need to restrict sample;

  age = year - yearmin_firm;
  if firmid = . then delete;
  if emp <= 0 then delete;
  if emp = . then delete;
  if year = . then delete;
run;

data bs1;
  set one;
  if year = 2003;
run;

proc sort data=bs1; by dind2;

data bs1 (drop=twosic);
  merge bs1 d.twonaics; by dind2;
  if dind3 = . then dind3 = twosic;
run;

data bs2;
  set one;
  if year = 2003 then delete;
run;

data one;
  set bs1 bs2;
run;

** firmid *** to identify entry and exit ********************************************;
data oneid (keep=year firmid emp);
  set one;
  if emp = . then delete;
run;

proc sort data=oneid; by year firmid;
run;

proc means noprint data=oneid;
  var emp;
  by year firmid;
output out=oneid sum=;
run;

data oneidforward (drop=emp);
  set oneid;
  year = year - 5;
  forward = 1;
run;

proc sort data=oneidforward;
  by year firmid;
run;

data oneid;
  set oneid;
  inc = 1;
run;

proc sort data=oneid;
  by year firmid;
run;

data d.oneid (keep=year firmid new exit);
  merge oneid oneidforward;
  by year firmid;
  exit = 0;
  new = 0;
  if forward = 1 and inc = . then new = 1;
  if inc = 1 and forward = . then exit = 1;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

** end of firmid with entry and exit dummy *****************************************************;


** aggregate employment by year **********************;
proc sort data=one; by year dind2;
run;

proc means noprint data=one;
  var emp;
  by year;
output out=empyear sum=empyear;
run;

data d2001;
  set empyear;
  if year = 2001;
  empyear2001 = empyear;
  dum = 1;
run;

data d2003;
  set empyear;
  if year = 2003;
  empyear2003 = empyear;
  dum = 1;
run;

proc sort data=d2001; by dum;
run;

proc sort data=d2003; by dum;
run;

data empyearforward (keep=year empyearforward);
  set empyear;
  if year = 2001 then delete;
  * for annual total of employment use 2003;
  year = year - 5;
  empyearforward = empyear;
run;

data empyear (keep=year dempyear empyear empyearforward);
  merge empyear empyearforward; by year;
  dempyear = empyearforward - empyear;
  if dempyear = . then delete;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

* dempyear is change in employment by year, empyear is level of employment by year;
* empyearforward is total employmenat by year five years later;

** now aggregate by industry ************************;
proc means data=one noprint;
  var emp;
  by year dind2;
output out=empind (keep=year dind2 empind) sum=empind;

data empindforward (keep=year dind2 empindforward dum);
  set empind;
  if year = 2003 then delete;
  if year = 2001 then year = 2003;
  * for annual total of employment use 2003;
  year = year - 5;
  empindforward = empind;
  dum = 1;
run;

proc sort data=empindforward; by dum;

data empindforward (drop=dum empyear2003 empyear2001);
  merge empindforward d2001 d2003;
  by dum;
  if year = 1998 then empindforward = empindforward*empyear2003/empyear2001; *adjust employment in 2001 so that total is equal to 2003;
run;

proc sort data=empindforward;
  by year dind2;
run;

data empind (keep=year dind2 dempind empind);
  merge empind empindforward;
  by year dind2;
  dempind = empindforward - empind;
  if dempind = . then delete;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

data empind;
  merge empind empyear; by year;
  if empyear = . then delete;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

* dempyear is change in employment by year, empyear is level of employment by year, empind is level of employment by industry;
* empyearforward is total employmenat by year five years later;
* dempdind is change in total employment by year and industry;

**** end total employment by industry and year **************************************;

** now change in employment by PLANT ***********************************************************;
proc sort data=one;
  by year lbdnum;
run;

data oneforward (keep=year dind4 lbdnum empforward firmidforward);
  set one;
  year = year - 5;
  empforward = emp;
  firmidforward = firmid;
  if year = 1998 then dind2 = dind3;  * two digit sic for new plants in 2003;
  dind4 = dind2;
run;

data one;  * one is now stacked data with t and t+1 data;
  merge one oneforward; by year lbdnum;  * match by plant id;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;

  demp = empforward - emp;  * surviving plants ;

  newplant = 0;
  exitplant = 0;
  changeowner  = 0;
  emp2 = emp;  * use this to calculate share of total employment by plant;

  ** surviving establishments that change ownership ******;
  if empforward ~= . and emp ~= . and firmid ~= firmidforward then changeowner = 1;

  ** new plants five years later;
  if emp = . then do;
      demp = empforward;
      emp2 = empforward;
      newplant = 1;
      firmid = firmidforward;
      dind2 = dind4;
  ** firmid of entrants is id of firm that owns the plant five years later;
  ** some of these plants will be owned by firms that exist at time t -- others will be firms that are brand new at t+1 (five years later;
  end;

  ** plants that exit five years later *********;
  if empforward = . then do;
      demp = - emp;
      exitplant = 1;
  * change in employment is minus employment at time t *****;
  end;


  if demp = . then delete;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

data oneb;  * sample of "exiting plants" because they change ownership;
  set one;
  if changeowner = 1;
  demp = - emp;  * change in employment is minus employment at time t;
  exitplant = 1;
  empforward = .;
  * surviving establishments that change ownership counted as exiter -- firmid is firm that owns plant at time t;
  * these are will also be considered new plants at t+1;
run;

data onec;  * sample of "entering" plants because they were bought ;
  set one;
  if changeowner = 1;
  demp = empforward;
  firmid = firmidforward;
  emp = .;
  newplant = 1;
  exitplant = 0;
run;

data oned;
  set one;
  if changeowner = 1 then delete;  * remove plants that change ownership;
run;

data one (drop=firmidforward);
  set oned oneb onec;
  if emp = . then emp = 0;
  if empforward = . then empforward = 0;
run;  * this now has stacked dataset including new plants in t+1 and surviving plants that switched ownership;

** end of stacked dataset *****************************************************************************************;

** now total employment by industry based on emp2 *********************************************************;
proc sort data=one; by year dind2;
run;

proc means data=one noprint;
  var emp2;
  by year dind2;
output out=one2 sum=emp2ind;
run;  *total employment based on emp2;

data one;
*  (keep=year firmid demp demporig emp empforward);
  merge one one2 empind; by year dind2;
  demporig = demp;
  share_plant = emp2/emp2ind;
  share_industry = empind/empyear;
  demp = demp - share_plant*(dempind - share_industry*dempyear);
*  demp = demporig;
  * remove this last part if we want adjusted change in employment;
  count = 1;
run;

** one has change in employment adjusted by industry and annual employment by plant **************************************;

** aggregate to firm level ************************************************;
proc sort data=one; by year firmid;
run;

proc means data=one noprint; by year firmid;
  var emp demp demporig empforward newplant exitplant count;
  output out=two sum=;
run;

data two;
  merge two d.oneid; by year firmid;
  if demp = . then delete;
  if newplant = . then newplant = 0;
  if exitplant = . then exitplant = 0;
  destabsh = (newplant - exitplant)/(count/2);
run;

* demp is total ADJUSTED change in employment among establishments owned by firm including entrants owned five years later;
* emp is total employment of firm at time t;
* empforward is total employment of firm at time t + 1;
* exit is indicator variable for exiting firm;
* new is indicator variable for new firm at END of period;
** end of aggregation to firm *********************************************;

** two_change two_entry and two_exit *****************************************;

data two_change (keep = year firmid dempsh demp demporig dplantsh noplantchange);
  set two;
  if exit = 0 and new = 0;  * restrict to incumbent firms;
  if emp = . then delete;
  avgemp = (empforward + emp)/2;
  if avgemp = . then delete;
  dempsh = demp/avgemp;
  inc = count - newplant - exitplant;
  dplantsh = (newplant - exitplant)/((2*inc + newplant + exitplant)/2);
  * change in employment as fraction of average employment -- this is what we plot on x-axis;
  noplantchange = 0;
  if dplantsh = 0 then noplantchange = 1;
run;
** two_change has change in employment over five years ************************;

proc means data=two_change;
  var noplantchange;
run;

data bs;
  set two_change;
  if noplantchange = 0;
run;

proc univariate data=bs;
  var dplantsh;
run;

proc reg data=two_change;
  model dempsh = dplantsh;
run;

data bspos;
  set two_change;
  if demp > 0;
  big = 0;
  if dplantsh > .05 then big = 1;
run;

proc sort; by big;

proc means data=bspos;
  by big;
  var dempsh;
output out=bspos mean=dempsh;

proc print data=bspos;

data bsneg;
  set two_change;
  if demp < 0;
  big = 0;
  if dplantsh < -.05 then big =1;
run;

proc sort; by big;

proc means data=bsneg;
  by big;
  var dempsh;
output out=bsneg mean=dempsh;

proc print data=bsneg;

** entry and exit *************************************************************;
data two_exit (keep=year firmid demp dempsh demporig);
  set two;
  if exit = 1;
  dempsh =  - 2;
run;

data two_entry (keep = year firmid demp dempsh demporig);
  set two;
  if new = 1;
  dempsh = 2;
  * year refers to entry year - 5;
run;

* dempsh is positive for entrants and growing incumbents;
* dempsh negative for exiters and incumbents that shrink;
** two_change (incumbents), two_entry, and two_exit are used to calculate JC and JD *******************;

** aggregate changes and entry and exit sample ***********************************;
data twochange_pos (keep=year firmid demp dempsh dempsh2 );
  set two_change two_entry;
  if demp > 0;
  if year > 2008 then delete;  * 2008 is last year with exit over next five years;
  if year < 1983 then delete;  * 1983 is first year with entry over next five years;
  dempsh2 = dempsh;
run;

data twochange_neg (keep=year firmid demp dempsh dempsh2 );
  set two_change two_exit;
  if demp < 0;  * only negative job creation or exit ;
  if year > 2008 then delete;  * 2008 is last year with exit over next five years;
  if year < 1983 then delete;  * 1976 is first year with entry over next five years;
  dempsh2 = -1* dempsh;  * make change positive, including exiting firms;
  demp = demp * -1;  * make job losses positive;
run;  * change back to negative;

** twochange_pos and twochange_neg are samples of job creation and destruction **********;

** total job creation and destruction ************;
proc sort data=twochange_pos; by year;
run;

proc means noprint data=twochange_pos;
  by year;
  var demp;
output out=jc sum=jc;
run;

proc sort data=two_entry; by year;
run;

proc means noprint data=two_entry;
  by year;
  var demp;
output out=entry sum=jc_entry;
run;

data two_small;
  set twochange_pos;
  if demp > 0;
  if dempsh2 < 1;
run;

proc sort data=two_small;
  by year;
run;

proc means data=two_small noprint;
  var demp;
  by year;
output out=two_smallpos sum=jc_small;
run;

data two_small2;
  set twochange_pos;
  if demp > 0;
  if dempsh2 < 2/3;
run;

proc sort data=two_small2;
  by year;
run;

proc means data=two_small2 noprint;
  var demp;
  by year;
output out=two_smallpos2 sum=jc_small2;
run;

proc sort data=twochange_neg; by year;
run;

proc means noprint data=twochange_neg;
  by year;
  var demp;
output out=jd sum=jd;
run;

data two_small;
  set twochange_neg;
  if demp > 0;
  if dempsh2 < 1;
run;

proc sort data=two_small;
  by year;
run;

proc means data=two_small noprint;
  var demp;
  by year;
output out=two_smallneg sum=jd_small;
run;


proc sort data=two_exit; by year;
run;

proc means noprint data=two_exit; by year;
  var demp;
output out=exit sum=jd_exit;
run;

data jc (keep = year jc jcrate jc_entry jc_small jc_small2 entrantshare);
  merge jc entry two_smallpos two_smallpos2 empyear;  * empyear has total employment in the two years;
  by year;
  jcrate = jc/((empyear + empyearforward)/2);
  entrantshare = jc_entry/empyearforward;
  jc_entry = jc_entry/jc;
  jc_small = jc_small/jc;
  jc_small2 = jc_small2/jc;
run;

data jd (keep = year jd jdrate jd_exit jd_small);
  merge jd exit two_smallneg empyear;
  by year;
  jdrate = jd/((empyear + empyearforward)/2);
  jd_exit = jd_exit/jd;
  jd_small = jd_small/jd;
run;

data jcjd;
  merge jc jd; by year;
run;

proc print data=jcjd;  ** aggregate job creation and destruction rate ***;
  var year jc jd jcrate jdrate jc_entry entrantshare jc_small jc_small2 jd_exit jd_small;
title1 ' JC and JD within industry';
run;

* keep original jc and jd files for bins later;
data jcorig;
  set jc;
run;

data jdorig;
  set jd;
run;

** end total ** adjusted ** job creation and job desruction ***********;

** job creation and job destruction not adjusted ***********************;
data twochange_pos (keep=year firmid demp dempsh dempsh2 );
  set two_change two_entry;
  if demporig > 0;
  demp = demporig;
  if year > 2008 then delete;  * 2008 is last year with exit over next five years;
  if year < 1983 then delete;  * 1979 is first year with entry over next five years;
  dempsh2 = dempsh;
run;

data twochange_neg (keep=year firmid demp dempsh dempsh2 );
  set two_change two_exit;
  if demporig < 0;  * only negative job creation or exit ;
  demp = demporig;
  if year > 2008 then delete;  * 2008 is last year with exit over next five years;
  if year < 1983 then delete;  * 1976 is first year with entry over next five years;
  dempsh2 = dempsh*-1;  * make change positive, including exiting firms;
  demp = demp * -1;  * make job losses positive;
run;  * change back to negative;

** total job creation and destruction ************;
proc sort data=twochange_pos; by year;
run;

proc means noprint data=twochange_pos;
  by year;
  var demp;
output out=jc sum=jc;
run;

proc sort data=two_entry; by year;
run;

proc means noprint data=two_entry;
  by year;
  var demp;
output out=entry sum=jc_entry;
run;

data two_small;
  set twochange_pos;
  if demp > 0;
  if dempsh2 < 1;
run;

proc sort data=two_small;
  by year;
run;

proc means data=two_small noprint;
  var demp;
  by year;
output out=two_smallpos sum=jc_small;
run;

proc sort data=twochange_neg; by year;
run;

proc means noprint data=twochange_neg;
  by year;
  var demp;
output out=jd sum=jd;
run;

data two_small;
  set twochange_neg;
  if demp > 0;
  if dempsh2 < 1;
run;

proc sort data=two_small;
  by year;
run;

proc means data=two_small noprint;
  var demp;
  by year;
output out=two_smallneg sum=jd_small;
run;

proc sort data=two_exit; by year;
run;

proc means noprint data=two_exit; by year;
  var demp;
output out=exit sum=jd_exit;
run;

data jc (keep = year jc jcrate jc_entry jc_small entrantshare);
  merge jc entry two_smallpos empyear;  * empyear has total employment in the two years;
  by year;
  entrantshare = jc_entry/empyearforward;
  jcrate = jc/((empyear + empyearforward)/2);
  jc_entry = jc_entry/jc;
  jc_small = jc_small/jc;

run;

data jd (keep = year jd jdrate jd_exit jd_small);
  merge jd exit two_smallneg empyear;
  by year;
  jdrate = jd/((empyear + empyearforward)/2);
  jd_exit = jd_exit/jd;
  jd_small = jd_small/jd;
run;

data jcjd;
  merge jc jd; by year;
run;

proc print data=jcjd;  ** aggregate job creation and destruction rate ***;
  var year jc jd jcrate jdrate jc_entry entrantshare jc_small jd_exit jd_small;
title2 '-';
title1 ' JC and JD without adjusting for industry effects ';
run;
** end total ** UNadjusted ** job creation and job desruction ***********;


** what follows can be deleted in the loop ***************************************************************;

** jc and destruction by bins of .05 *******************;
data twochange_pos (keep=year firmid demp dempsh dempsh2 );
  set two_change two_entry;
  if demp > 0;

  dempsh2 = .;

  ** this next section can be commented out when looking over the 1000 samples *****;
  if dempsh < .05 then dempsh2 = .025;
  if dempsh >= .05 AND dempsh < .10 then dempsh2 = .075;
  if dempsh >= .10 AND dempsh < .15 then dempsh2 = .125;
  if dempsh >= .15 AND dempsh < .20 then dempsh2 = .175;
  if dempsh >= .20 AND dempsh < .25 then dempsh2 = .225;
  if dempsh >= .25 AND dempsh < .30 then dempsh2 = .275;
  if dempsh >= .30 AND dempsh < .35 then dempsh2 = .325;
  if dempsh >= .35 AND dempsh < .40 then dempsh2 = .375;
  if dempsh >= .40 AND dempsh < .45 then dempsh2 = .425;
  if dempsh >= .45 AND dempsh < .50 then dempsh2 = .475;
  if dempsh >= .50 AND dempsh < .55 then dempsh2 = .525;
  if dempsh >= .55 AND dempsh < .60 then dempsh2 = .575;
  if dempsh >= .60 AND dempsh < .65 then dempsh2 = .625;
  if dempsh >= .65 AND dempsh < .70 then dempsh2 = .675;
  if dempsh >= .70 AND dempsh < .75 then dempsh2 = .725;
  if dempsh >= .75 AND dempsh < .80 then dempsh2 = .775;
  if dempsh >= .80 AND dempsh < .85 then dempsh2 = .825;
  if dempsh >= .85 AND dempsh < .90 then dempsh2 = .875;
  if dempsh >= .90 AND dempsh < .95 then dempsh2 = .925;
  if dempsh >= .95 AND dempsh < 1.00 then dempsh2 = .975;
  if dempsh >= 1.00 AND dempsh < 1.05 then dempsh2 = 1.025;
  if dempsh >= 1.05 AND dempsh < 1.10 then dempsh2 = 1.075;

  if dempsh >= 1.10 AND dempsh < 1.15 then dempsh2 = 1.125;
  if dempsh >= 1.15 AND dempsh < 1.20 then dempsh2 = 1.175;
  if dempsh >= 1.20 AND dempsh < 1.25 then dempsh2 = 1.225;
  if dempsh >= 1.25 AND dempsh < 1.30 then dempsh2 = 1.275;
  if dempsh >= 1.30 AND dempsh < 1.35 then dempsh2 = 1.325;
  if dempsh >= 1.35 AND dempsh < 1.40 then dempsh2 = 1.375;
  if dempsh >= 1.40 AND dempsh < 1.45 then dempsh2 = 1.425;
  if dempsh >= 1.45 AND dempsh < 1.50 then dempsh2 = 1.475;
  if dempsh >= 1.50 AND dempsh < 1.55 then dempsh2 = 1.525;
  if dempsh >= 1.55 AND dempsh < 1.60 then dempsh2 = 1.575;
  if dempsh >= 1.60 AND dempsh < 1.65 then dempsh2 = 1.625;
  if dempsh >= 1.65 AND dempsh < 1.70 then dempsh2 = 1.675;
  if dempsh >= 1.70 AND dempsh < 1.75 then dempsh2 = 1.725;
  if dempsh >= 1.75 AND dempsh < 1.80 then dempsh2 = 1.775;
  if dempsh >= 1.80 AND dempsh < 1.85 then dempsh2 = 1.825;
  if dempsh >= 1.85 AND dempsh < 1.90 then dempsh2 = 1.875;
  if dempsh >= 1.90 AND dempsh < 1.95 then dempsh2 = 1.925;
  if dempsh >= 1.95 AND dempsh < 2 then dempsh2 = 1.975;
  if dempsh = 2 then dempsh2 = 2;   * entrants;
run;

data twochange_neg (keep=year firmid demp dempsh dempsh2 );
  set two_change two_exit;
  if demp < 0;  * only negative job creation or exit ;

  dempsh2 = .;

  dempsh = dempsh*-1;  * make change positive, including exiting firms;

  if dempsh < .05 then dempsh2 = .025;
  if dempsh >= .05 AND dempsh < .10 then dempsh2 = .075;
  if dempsh >= .10 AND dempsh < .15 then dempsh2 = .125;
  if dempsh >= .15 AND dempsh < .20 then dempsh2 = .175;
  if dempsh >= .20 AND dempsh < .25 then dempsh2 = .225;
  if dempsh >= .25 AND dempsh < .30 then dempsh2 = .275;
  if dempsh >= .30 AND dempsh < .35 then dempsh2 = .325;
  if dempsh >= .35 AND dempsh < .40 then dempsh2 = .375;
  if dempsh >= .40 AND dempsh < .45 then dempsh2 = .425;
  if dempsh >= .45 AND dempsh < .50 then dempsh2 = .475;
  if dempsh >= .50 AND dempsh < .55 then dempsh2 = .525;
  if dempsh >= .55 AND dempsh < .60 then dempsh2 = .575;
  if dempsh >= .60 AND dempsh < .65 then dempsh2 = .625;
  if dempsh >= .65 AND dempsh < .70 then dempsh2 = .675;
  if dempsh >= .70 AND dempsh < .75 then dempsh2 = .725;
  if dempsh >= .75 AND dempsh < .80 then dempsh2 = .775;
  if dempsh >= .80 AND dempsh < .85 then dempsh2 = .825;
  if dempsh >= .85 AND dempsh < .90 then dempsh2 = .875;
  if dempsh >= .90 AND dempsh < .95 then dempsh2 = .925;
  if dempsh >= .95 AND dempsh < 1.00 then dempsh2 = .975;
  if dempsh >= 1.00 AND dempsh < 1.05 then dempsh2 = 1.025;
  if dempsh >= 1.05 AND dempsh < 1.10 then dempsh2 = 1.075;

  if dempsh >= 1.10 AND dempsh < 1.15 then dempsh2 = 1.125;
  if dempsh >= 1.15 AND dempsh < 1.20 then dempsh2 = 1.175;
  if dempsh >= 1.20 AND dempsh < 1.25 then dempsh2 = 1.225;
  if dempsh >= 1.25 AND dempsh < 1.30 then dempsh2 = 1.275;
  if dempsh >= 1.30 AND dempsh < 1.35 then dempsh2 = 1.325;
  if dempsh >= 1.35 AND dempsh < 1.40 then dempsh2 = 1.375;
  if dempsh >= 1.40 AND dempsh < 1.45 then dempsh2 = 1.425;
  if dempsh >= 1.45 AND dempsh < 1.50 then dempsh2 = 1.475;
  if dempsh >= 1.50 AND dempsh < 1.55 then dempsh2 = 1.525;
  if dempsh >= 1.55 AND dempsh < 1.60 then dempsh2 = 1.575;
  if dempsh >= 1.60 AND dempsh < 1.65 then dempsh2 = 1.625;
  if dempsh >= 1.65 AND dempsh < 1.70 then dempsh2 = 1.675;
  if dempsh >= 1.70 AND dempsh < 1.75 then dempsh2 = 1.725;
  if dempsh >= 1.75 AND dempsh < 1.80 then dempsh2 = 1.775;
  if dempsh >= 1.80 AND dempsh < 1.85 then dempsh2 = 1.825;
  if dempsh >= 1.85 AND dempsh < 1.90 then dempsh2 = 1.875;
  if dempsh >= 1.90 AND dempsh < 1.95 then dempsh2 = 1.925;
  if dempsh >= 1.95 AND dempsh < 2 then dempsh2 = 1.975;
  if dempsh = 2 then dempsh2 = 2;

  demp = demp * -1;  * make job losses positive;
  dempsh2 = dempsh2*-1;
  dempsh = dempsh*-1;
run;  * change back to negative;

proc sort data=twochange_pos; by year dempsh2;

proc means data=twochange_pos noprint; by year dempsh2;
  var demp ;
  output out=pos sum(demp)= ;
run;

proc sort data=twochange_neg; by year dempsh2;

proc means data=twochange_neg noprint; by year dempsh2;
  var demp ;
  output out=neg sum(demp)= ;
run;

* demp is now total job creation/destruction in absolute terms in by dempsh2;

** end jc and destruction by bins **********************;

** merge aggregate jc and jd ***************************;
data pos;
  merge pos jcorig jdorig; by year;
  jrate1 = demp/jc;  *jrate1 is job creation in each bin as a share of total job creation (for dempsh2 > 0);
  jrate2 = jrate1*jcrate; * jrate2 is job creation share * total job creation rate;
run;

proc means data=pos noprint;
  by year;
  var jrate1;
output out=bs sum=;
run;

proc print data=bs;
  var year jrate1;
run;

data neg;
  merge neg jcorig jdorig; by year;
  jrate1 = demp/jd; * jcrate1 is job destruction as share of total job destruction;
  jrate2 = jrate1*jdrate; * jrate2 is job destruction share * total job destruction rate;
run;

proc means data=pos noprint;
  by year;
  var jrate1;
output out=bs sum=;
run;

proc print data=bs;
  var year jrate1;
run;

data twochange;
  set pos neg;
  if dempsh2 = . then delete;
  year2 = .;
  if year = 1983 or year = 1988 then year2 = 1988;
  if year = 1993 or year = 1998 then year2 = 1998;
  if year = 2003 or year = 2008 then year2 = 2008;
  if year2 = . then delete;
  year = year2;
run;

proc sort data=twochange; by year dempsh2;
run;

proc means data=twochange noprint; by year dempsh2;
  var jrate1;
output out=twochange mean=;

proc sort data=twochange; by year dempsh2;
run;

proc print data=twochange;
  var year dempsh2 jrate1 ;
run;

proc means data=twochange noprint;
  by year;
  var jrate1;
output out=bs sum=;
run;

proc print data=bs;
  var year jrate1;
run;

* end proclbd3.sas ******;

