


/*
Program 20: proclbd3oneyear.sas
*/


* proclbd3oneyear.sas;

* libname c "/economic/lbd/microdata";
* libname d "/rdcprojects/ch/ch01440/data";

* library c is not used in this sas file and the directory structure of raw lbd data has changed;
libname d "/projects/data";


* change entrants to firms in year t+1 not in data in year t;
** adjust JD and JC at four digit SIC (until 2001) and six digit NAICS (after 2001);
** change over one year ****;

** crosswalk between two digit sic and naics based on 2001 and 2002 data ******;
data bs;
  set d.lbd (keep=year naics sic emp);
  if year = 2001 or year = 2002;
  * twosic = floor(sic/100);
  * twonaics = floor(naics/1000);
  twosic = sic;
  twonaics = naics;
  if twosic = . then delete;
  if twonaics = . then delete;
run;

proc sort data=bs; by twonaics twosic;
run;

proc means data=bs noprint;
  by twonaics twosic;
  var emp;
output out=bs2 sum=empmax;
run;

proc sort data=bs2 out=bs3;
  by twonaics descending empmax;
run;

proc sort data=bs3 out=bs3 nodupkey;
  by twonaics;
run;

data d.twonaicsoneyear (keep=dind2 twosic);
  set bs3;
  dind2 = twonaics;
run;

proc sort data=d.twonaicsoneyear; by dind2;
run;

** end crosswalk **************************************************************;

data one (keep=year firmid age lbdnum emp dind2 dind3);
  set d.lbd;
  * if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2001 or year = 2003 or year = 2008 or year = 2013;
  * 1983 to 1988, 1988 to 1993, 1993 to 1998, 1998 to 2003, 2003 to 2008, 2008 to 2013;

  if year < 1983 then delete;
*  if year > 2003 then delete;

  * dind2 is two digit sic or 3 digit naics *****;
  * dind2 = floor(sic/100);
  dind2 = sic;
  if sic = . then dind2 = sic2;
*  if sic = . then dind2 = floor(sic2/100);
  dind3 = dind2; *use for 2002;
*  if year > 2001 then dind2 = floor(naics/1000);
  if year > 2001 then dind2 = naics;

  * dind2 is four digit sic until 2001, six digit naics after 2001;
  * dind3 is four digit sic for all years;

  if dind2 = . then delete;
  *** end dind2 *********************************;

  twonaics=floor(naics/1000);

* need to restrict sample ;

  age = year - yearmin_firm;
  if firmid = . then delete;
  if emp <= 0 then delete;
  if emp = . then delete;
  if year = . then delete;
run;

data bs1;
  set one;
  if year = 2002;
run;

proc means;
  var dind2 dind3;
run;

proc sort data=bs1; by dind2;

data bs1 (drop=twosic);
  merge bs1 d.twonaicsoneyear; by dind2;
  if dind3 = . then dind3 = twosic;
run;

data bs2;
  set one;
  if year = 2002 then delete;
run;

data one;
  set bs1 bs2;
run;
** one has dind3 defined by sic ;

** firmid *** to identify entry and exit ********************************************;
data oneid (keep=year firmid emp age);
  set one;
  if emp = . then delete;
run;

proc sort data=oneid; by year firmid;
run;

proc means noprint data=oneid;
  var emp age;
  by year firmid;
output out=oneid sum(emp)=emp max(age)=age;
run;

data oneidforward (drop=emp age);
  set oneid;
  year = year - 1;
  forward = 1;
run;

proc sort data=oneidforward;
  by year firmid;
run;

data oneid;
  set oneid;
  inc = 1;
run;

proc sort data=oneid;
  by year firmid;
run;

data d.oneidoneyear (keep=year firmid new exit age);
  merge oneid oneidforward;
  by year firmid;
  exit = 0;
  new = 0;
  if forward = 1 and inc = . then new = 1;
  if inc = 1 and forward = . then exit = 1;
  if year < 1983 then delete;
  if year > 2012 then delete;
*  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

** end of firmid with entry and exit dummy *****************************************************;


** aggregate employment by year **********************;
proc sort data=one; by year dind2;
run;

proc means noprint data=one;
  var emp;
  by year;
output out=empyear sum=empyear;
run;

data empyearforward (keep=year empyearforward);
  set empyear;
  year = year - 1;
  empyearforward = empyear;
run;

data empyear (keep=year dempyear empyear empyearforward);
  merge empyear empyearforward; by year;
  dempyear = empyearforward - empyear;
  if dempyear = . then delete;
  if year < 1983 then delete;
  if year > 2012 then delete;
  * if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

* dempyear is change in employment by year, empyear is level of employment by year;
* empyearforward is total employmenat by year five years later;

** now aggregate by industry ************************;
proc means data=one noprint;
  var emp;
  by year dind2;
output out=empind (keep=year dind2 empind) sum=empind;

proc sort data=one; by year dind3;
run;

proc means data=one noprint;
  var emp;
  by year dind3;
output out=empind2 sum=empind;

data empind2 (keep=year empindforward dind2);
  set empind2;
  if year = 2002;
  year = year - 1;
  empindforward = empind;
  dind2 = dind3;
run;

data empindforward (keep=year dind2 empindforward dum);
  set empind;
  year = year - 1;
  empindforward = empind;
  if year = 2001 then delete;
run;

data empindforward;
  set empindforward empind2;
run;
* 2001 now based on sic;

proc sort data=empindforward;
  by year dind2;
run;

data empind (keep=year dind2 dempind empind);
  merge empind empindforward;
  by year dind2;
  dempind = empindforward - empind;
  if dempind = . then delete;
  if year < 1983 then delete;
  if year > 2012 then delete;
*  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

data empind;
  merge empind empyear; by year;
  if empyear = . then delete;
  if year < 1983 then delete;
  if year > 2012 then delete;
*  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

* dempyear is change in employment by year, empyear is level of employment by year, empind is level of employment by industry;
* empyearforward is total employmenat by year five years later;
* dempdind is change in total employment by year and industry;

proc means data=empind;
by year;

**** end total employment by industry and year **************************************;

** now change in employment by PLANT ***********************************************************;
proc sort data=one;
  by year lbdnum;
run;

data oneforward (keep=year dind4 lbdnum empforward firmidforward);
  set one;
  year = year - 1;
  empforward = emp;
  firmidforward = firmid;
  if year = 2001 then dind2 = dind3;  * two digit sic for new plants in 2002;
  dind4 = dind2;
run;

data one;
  merge one oneforward; by year lbdnum;  * match by plant id;
*  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
  if year < 1983 then delete;
  if year > 2012 then delete;

  demp = empforward - emp;  * surviving plants ;

  newplant = 0;
  exitplant = 0;
  changeowner  = 0;
  emp2 = emp;  * use this to calculate share of total employment by plant;

  ** surviving establishments that change ownership ******;
  if empforward ~= . and emp ~= . and firmid ~= firmidforward then changeowner = 1;

  ** new plants five years later;
  if emp = . then do;
      demp = empforward;
      emp2 = empforward;
      newplant = 1;
      firmid = firmidforward;
      dind2 = dind4;
  ** firmid of entrants is id of firm that owns the plant five years later;
  ** some of these plants will be owned by firms that exist at time t -- others will be firms that are brand new at t+1 (five years later;
  end;

  ** plants that exit five years later *********;
  if empforward = . then do;
      demp = - emp;
      exitplant = 1;
  * change in employment is minus employment at time t *****;
  end;


  if demp = . then delete;
*  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

data oneb;
  set one;
  if changeowner = 1;
  demp = - emp;  * change in employment is minus employment at time t;
  exitplant = 1;
  empforward = .;
  * surviving establishments that change ownership counted as exiter -- firmid is firm that owns plant at time t;
  * these are will also be considered new plants at t+1;
run;

data onec;
  set one;
  if changeowner = 1;
  demp = empforward;
  firmid = firmidforward;
  emp = .;
  newplant = 1;
  exitplant = 0;
run;

data oned;
  set one;
  if changeowner = 1 then delete;
run;

data one (drop=firmidforward);
  set oned oneb onec;
  if emp = . then emp = 0;
  if empforward = . then empforward = 0;
run;  * this now has stacked dataset including new plants in t+1 and surviving plants that switched ownership;

** end of stacked dataset *****************************************************************************************;

** now total employment by industry based on emp2 *********************************************************;
proc sort data=one; by year dind2;
run;

proc means data=one noprint;
  var emp2;
  by year dind2;
output out=one2 sum=emp2ind;
run;  *total employment based on emp2;

data one;
*  (keep=year firmid demp demporig emp empforward);
  merge one one2 empind; by year dind2;
  demporig = demp;
  share_plant = emp2/emp2ind;
  share_industry = empind/empyear;
  demp = demp - share_plant*(dempind - share_industry*dempyear);
*  demp = demporig;
  * remove this last part if we want adjusted change in employment;
  count = 1;
run;

** one has change in employment adjusted by industry and annual employment by plant **************************************;

** aggregate to firm level ************************************************;
proc sort data=one; by year firmid;
run;

proc means data=one noprint; by year firmid;
  var emp demp demporig empforward newplant exitplant count;
  output out=two sum=;
run;

data two;
  merge two d.oneidoneyear; by year firmid;
  if demp = . then delete;
  if newplant = . then newplant = 0;
  if exitplant = . then exitplant = 0;
  destabsh = (newplant - exitplant)/(count/2);
run;

* demp is total ADJUSTED change in employment among establishments owned by firm including entrants owned five years later;
* emp is total employment of firm at time t;
* empforward is total employment of firm at time t + 1;
* exit is indicator variable for exiting firm;
* new is indicator variable for new firm at END of period;
** end of aggregation to firm *********************************************;

** two_change two_entry and two_exit *****************************************;

data two_change (keep = year firmid dempsh demp demporig dplantsh noplantchange age new);
  set two;
  if exit = 0 and new = 0;  * restrict to incumbent firms;
  if emp = . then delete;
  avgemp = (empforward + emp)/2;
  if avgemp = . then delete;
  dempsh = demp/avgemp;
  inc = count - newplant - exitplant;
  dplantsh = (newplant - exitplant)/((2*inc + newplant + exitplant)/2);
  * change in employment as fraction of average employment -- this is what we plot on x-axis;
  noplantchange = 0;
  if dplantsh = 0 then noplantchange = 1;
run;
** two_change has change in employment over five years ************************;

proc means data=two_change;
  var noplantchange;
run;

data bs;
  set two_change;
  if noplantchange = 0;
run;

proc univariate data=bs;
  var dplantsh;
run;

proc reg data=two_change;
  model dempsh = dplantsh;
run;

data bspos;
  set two_change;
  if demp > 0;
  big = 0;
  if dplantsh > .05 then big = 1;
run;

proc sort; by big;

proc means data=bspos;
  by big;
  var dempsh;
output out=bspos mean=dempsh;

proc print data=bspos;

data bsneg;
  set two_change;
  if demp < 0;
  big = 0;
  if dplantsh < -.05 then big =1;
run;

proc sort; by big;

proc means data=bsneg;
  by big;
  var dempsh;
output out=bsneg mean=dempsh;

proc print data=bsneg;

** entry and exit *************************************************************;
data two_exit (keep=year firmid demp dempsh demporig);
  set two;
  if exit = 1;
  dempsh =  - 2;
run;

data two_entry (keep = year firmid demp dempsh demporig);
  set two;
  if new = 1;
  dempsh = 2;
  * year refers to entry year - 5;
run;

* dempsh is positive for entrants and growing incumbents;
* dempsh negative for exiters and incumbents that shrink;
** two_change (incumbents), two_entry, and two_exit are used to calculate JC and JD *******************;

** aggregate changes and entry and exit sample ***********************************;
data twochange_pos (keep=year firmid demp dempsh dempsh2 age);
  set two_change two_entry;
  if demp > 0;
  if year > 2012 then delete;  * 2008 is last year with exit over next five years;
  if year < 1983 then delete;  * 1983 is first year with entry over next five years;
  dempsh2 = dempsh;
run;

data twochange_neg (keep=year firmid demp dempsh dempsh2 age);
  set two_change two_exit;
  if demp < 0;  * only negative job creation or exit ;
  if year > 2012 then delete;  * 2008 is last year with exit over next five years;
  if year < 1983 then delete;  * 1976 is first year with entry over next five years;
  dempsh2 = -1* dempsh;  * make change positive, including exiting firms;
  demp = demp * -1;  * make job losses positive;
run;  * change back to negative;

** twochange_pos and twochange_neg are samples of job creation and destruction **********;

** total job creation and destruction ************;
proc sort data=twochange_pos; by year;
run;

proc means noprint data=twochange_pos;
  by year;
  var demp;
output out=jc sum=jc;
run;

proc sort data=two_entry; by year;
run;

proc means noprint data=two_entry;
  by year;
  var demp;
output out=entry sum=jc_entry;
run;

data two_small;
  set twochange_pos;
  if demp > 0;
  if dempsh2 < 1;
run;

proc sort data=two_small;
  by year;
run;

proc means data=two_small noprint;
  var demp;
  by year;
output out=two_small sum=jc_small;
run;

** job creation in age bins *******************;
data two_five;
  set two_change;
  if demp > 0;
  if new = 0;
  if age <= 4;
run;

proc sort data=two_five;
  by year;
run;

data two_ten;
  set two_change;
  if demp > 0;
  if new = 0;
  if age >= 5 and age <= 9;
run;

proc sort data=two_ten;
  by year;
run;

data two_fifteen;
  set two_change;
  if demp > 0;
  if new = 0;
  if age <= 10 and age <= 14;
run;

proc sort data=two_fifteen;
  by year;
run;

proc means data=two_five noprint;
  var demp;
  by year;
output out=two_five sum=jc_five;
run;

proc means data=two_ten noprint;
  var demp;
  by year;
output out=two_ten sum=jc_ten;
run;

proc means data=two_fifteen noprint;
  var demp;
  by year;
output out=two_fifteen sum=jc_fifteen;
run;
** end job creation in age bins;

** now for job destruction by age bins;

data neg_five;
  set two_change;
  if demp < 0;
  if age <= 4;
run;

proc sort data=neg_five;
  by year;
run;

data neg_ten;
  set two_change;
  if demp < 0;
  if age >= 5 and age <= 9;
run;

proc sort data=neg_ten;
  by year;
run;

data neg_fifteen;
  set two_change;
  if demp < 0;
  if age <= 10 and age <= 14;
run;

proc sort data=neg_fifteen;
  by year;
run;

proc means data=neg_five noprint;
  var demp;
  by year;
output out=neg_five sum=jd_five;
run;

proc means data=neg_ten noprint;
  var demp;
  by year;
output out=neg_ten sum=jd_ten;
run;

proc means data=neg_fifteen noprint;
  var demp;
  by year;
output out=neg_fifteen sum=jd_fifteen;
run;
** end job destruction by age bins;

proc sort data=twochange_neg; by year;
run;

proc means noprint data=twochange_neg;
  by year;
  var demp;
output out=jd sum=jd;
run;

proc sort data=two_exit; by year;
run;

proc means noprint data=two_exit; by year;
  var demp;
output out=exit sum=jd_exit;
run;

data jc (keep = year jc jcrate jc_entry entrantshare jc_small jc_five jc_ten jc_fifteen);
  merge jc entry two_small two_five two_ten two_fifteen empyear;  * empyear has total employment in the two years;
  by year;
  entrantshare = jc_entry/empyearforward;
  jcrate = jc/((empyear + empyearforward)/2);
  jc_entry = jc_entry/jc;
  jc_small = jc_small/jc;
  jc_five = jc_five/jc;
  jc_ten = jc_ten/jc;
  jc_fifteen = jc_fifteen/jc;
run;

data jd (keep = year jd jdrate jd_exit jd_five jd_ten jd_fifteen);
  merge jd exit empyear neg_five neg_ten neg_fifteen;
  by year;
  jdrate = jd/((empyear + empyearforward)/2);
  jd_exit = jd_exit/jd;
  jd_five = jd_five/jd;
  jd_ten = jd_ten/jd;
  jd_fifteen = jd_fifteen/jd;
run;

data jcjd;
  merge jc jd; by year;
run;

proc print data=jcjd;  ** aggregate job creation and destruction rate ***;
  var year jc jd jcrate jdrate jc_entry jc_small entrantshare jc_five jc_ten jc_fifteen jd_exit jd_five jd_ten jd_fifteen;
title1 ' JC and JD within industry, annual estimates';
run;
** end total ** adjusted ** job creation and job desruction ***********;

data jcjd;
  set jcjd;
  year2 = 1988;
  if year < 1993 then year2 = 1988;
  if year >= 1993 and year < 2003 then year2 = 1998;
  if year >= 2003 then year2 = 2008;
run;

proc sort data=jcjd;
  by year2;
run;

proc means data=jcjd noprint;
  var jc jd jcrate jdrate jc_entry jc_small jc_five entrantshare jc_ten jc_fifteen jd_exit jd_five jd_ten jd_fifteen;
  by year2;
output out=jcjd mean=;

proc print data=jcjd;
  var year2 jc jd jcrate jdrate jc_entry entrantshare jc_small jd_exit;
title1 ' JC and JD within industry, mean over ten years;
run;


* end proclbd3oneyear.sas *******************;
