/*
Program 24: replicate3.sas
*/


* replicate3.sas;

* directory needs to be changed;

libname c "/economic/lbd/microdata";
libname d "/rdcprojects/ch/ch01440/data";


data one (keep=year dind2 firmid emp yearmax_firm yearmin_firm age lbdnum);
  set d.lbd;
  if year = 1983 or year = 1988 or year = 1991 or year = 1993 or year = 1998 or year = 2001 or year = 2003 or year = 2008 or year = 2013;
  twonaics=floor(naics/1000);

* sample needs to be restricted;

  age = year - yearmin_firm;
  if firmid = . then delete;
  if emp <= 0 then delete;
  if emp = . then delete;
  if year = . then delete;
  dind2 = floor(sic/100);
  if year > 2001 then dind2 = floor(naics/1000);
run;

data bs1;
  set one;
  if year = 2003;
run;

proc sort data=bs1; by dind2;

data bs1 (drop=twosic);
  merge bs1 d.twonaics; by dind2;
  if dind3 = . then dind3 = twosic;
run;

data bs2;
  set one;
  if year = 2003 then delete;
run;

data one;
  set bs1 bs2;
run;

proc sort data=one; by firmid;
run;
** one is master dataset *************************************************;

data d.big;
  stop;
run;

*** start macro which loops over proclbd2 and proclbd3 *****************************;
%macro sample;

%do i=1 %to I;  * sample number, goes from 1 to I; number redacted in disclosure review
  %do j=1 %to J;  * replicate number, goes from 1 to J; number redacted in disclosure review

data firmid;
    set d.firmid&i;
    if replicate = &j;
run;

proc sort data=firmid; by firmid;
run;

data oneb;
  merge one firmid; by firmid;
  if replicate = . then delete;
run;
** oneb is dataset used for each loop ***********************************************;

** firmid *** to identify entry and exit ********************************************;
data oneid (keep=year firmid emp);
  set oneb;
  if emp = . then delete;
run;

proc sort data=oneid; by year firmid;
run;

proc means noprint data=oneid;
  var emp;
  by year firmid;
output out=oneid sum=;
run;

data oneidforward (drop=emp);
  set oneid;
  year = year - 5;
  forward = 1;
run;

proc sort data=oneidforward;
  by year firmid;
run;

data oneid;
  set oneid;
  inc = 1;
run;

proc sort data=oneid;
  by year firmid;
run;

data oneid (keep=year firmid new exit);
  merge oneid oneidforward;
  by year firmid;
  exit = 0;
  new = 0;
  if forward = 1 and inc = . then new = 1;
  if inc = 1 and forward = . then exit = 1;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

** end of firmid with entry and exit dummy *****************************************************;


** beginning of proclbd2.sas ***********************************************************************;
data onec;
  set oneb;
  if year = 2001 then delete;
run;  **onec drops 2001 data;

proc sort data=onec; by year firmid;
run;

** aggregate to firm level ************************************************;
proc means data=onec noprint; by year firmid;
  var emp yearmin_firm yearmax_firm age;
  output out=two mean(yearmin_firm yearmax_firm)= sum(emp)= max(age)=;
run;

data two;
  set two;
  exit5 = 0;
  if yearmax_firm < year + 5 then exit5 = 1;
run;

** average size *************;
proc means data=two noprint;
  var emp;
  by year;
output out=empavg (keep=year empavg) mean=empavg;

proc means data=two noprint;
  var emp;
  wgt emp;
by year;
output out=wempavg (keep=year empmedian) mean=empmedian;
run;

data two;
  merge two empavg;
  by year;
  entrant = 0;
  big = 0;
  if age <= 4 then entrant = 1;
  if emp > empavg then big = 1;
  count = 1;
  lemp = log(emp);
run;
** two is dataset with firm aggregates ************************************;

proc sort data=two; by year entrant;

proc means data=two noprint; by year;
  var emp count lemp exit5;
  output out=sum mean(exit5)=exit5_all sum(emp count)=empyear totnfirm std(lemp)=sdlemp;
run;

proc means data=two noprint; by year entrant;
  var emp count lemp exit5;
  output out=entrant mean(emp exit5)=empent exit5_entrant sum(emp count)=empentsum nfirm_entrant std(lemp)=sdlemp_entrant;
run;

data entrant1 (keep = year empent empentsum nfirm_entrant sdlemp_entrant exit5_entrant);
  set entrant;
  if entrant = 1;
run;

data entrant2 (keep = year empinc);
  set entrant;
  if entrant = 0;
  empinc = empent;
run;

proc sort data=two; by year big;

proc means data=two noprint; by year big;
  var exit5;
  output out=exit mean=;
run;

data exit1 (keep = year exitbig);
  set exit;
  if big = 1;
  exitbig = exit5/5;
run;

data exit2 (keep = year exitsmall);
  set exit;
  if big = 0;
  exitsmall = exit5/5;
run;

data all;
  merge sum entrant1 entrant2 exit1 exit2 empavg wempavg; by year;
  entrantshare = empentsum/empyear;
  entrantfirmshare = nfirm_entrant/totnfirm;
  empyear = empyear/1000;
  exit5_all = exit5_all/5;
  exit5_entrant = exit5_entrant/5;
run;

data forward (keep=year empyearforward);
  set all (keep=year empyear);
  year = year - 5;
  empyearforward = empyear;
run;

data bs;
  set all (keep=year empyear);
run;

data bs (keep=year empgrowth);
  merge bs forward; by year;
  empgrowth = (log(empyearforward/empyear))/5;
  year2 = .;
  if year = 1983 or year = 1988 then year2 = 1988;
  if year = 1993 or year = 1998 then year2 = 1998;
  if year = 2003 or year = 2008 then year2 = 2008;
  if year2 = . then delete;
  year = year2;
run;

proc sort data=bs; by year;

proc means data=bs noprint;
  var empgrowth;
  by year;
output out=empgrowth mean=;

data datatoappend (drop=_type_ _freq_);
  merge all empgrowth; by year;
  if empgrowth = . then delete;
  sample = &i;
  replicate = &j;
run;

** end of proclbd2.sas ********************************;

** proclbd3.sas **************************************************************************;


** aggregate employment by year **********************;
proc sort data=oneb; by year dind2;  *oneb includes 2001 data;
run;

proc means noprint data=oneb;
  var emp;
  by year;
output out=empyear sum=empyear;
run;

data d2001;
  set empyear;
  if year = 2001;
  empyear2001 = empyear;
  dum = 1;
run;

data d2003;
  set empyear;
  if year = 2003;
  empyear2003 = empyear;
  dum = 1;
run;

proc sort data=d2001; by dum;
run;

proc sort data=d2003; by dum;
run;

data empyearforward (keep=year empyearforward);
  set empyear;
  if year = 2001 then delete;
  * for annual total of employment use 2003;
  year = year - 5;
  empyearforward = empyear;
run;

data empyear (keep=year dempyear empyear empyearforward);
  merge empyear empyearforward; by year;
  dempyear = empyearforward - empyear;
  if dempyear = . then delete;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

* dempyear is change in employment by year, empyear is level of employment by year;
* empyearforward is total employmenat by year five years later;

** now aggregate by industry ************************;
proc means data=oneb noprint;  *oneb includes 2001 data;
  var emp;
  by year dind2;
output out=empind (keep=year dind2 empind) sum=empind;

data empindforward (keep=year dind2 empindforward dum);
  set empind;
  if year = 2003 then delete;
  if year = 2001 then year = 2003;
  * for annual total of employment use 2003;
  year = year - 5;
  empindforward = empind;
  dum = 1;
run;

proc sort data=empindforward; by dum;

data empindforward (drop=dum empyear2003 empyear2001);
  merge empindforward d2001 d2003;
  by dum;
  if year = 1998 then empindforward = empindforward*empyear2003/empyear2001; *adjust employment in 2001 so that total is equal to 2003;
run;

proc sort data=empindforward;
  by year dind2;
run;

data empind (keep=year dind2 dempind empind);
  merge empind empindforward;
  by year dind2;
  dempind = empindforward - empind;
  if dempind = . then delete;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

data empind;
  merge empind empyear; by year;
  if empyear = . then delete;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

* dempyear is change in employment by year, empyear is level of employment by year, empind is level of employment by industry;
* empyearforward is total employmenat by year five years later;
* dempdind is change in total employment by year and industry;

**** end total employment by industry and year **************************************;

** now change in employment by PLANT ***********************************************************;
proc sort data=onec;
  by year lbdnum;
run;

data oneforward (keep=year dind4 lbdnum empforward firmidforward);
  set onec;
  year = year - 5;
  empforward = emp;
  firmidforward = firmid;
  if year = 1998 then dind2 = dind3;  * two digit sic for new plants in 2003;
  dind4 = dind2;
run;

data onec;
  merge onec oneforward; by year lbdnum;  * match by plant id;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;

  demp = empforward - emp;  * surviving plants ;

  newplant = 0;
  exitplant = 0;
  changeowner  = 0;
  emp2 = emp;  * use this to calculate share of total employment by plant;

  ** surviving establishments that change ownership ******;
  if empforward ~= . and emp ~= . and firmid ~= firmidforward then changeowner = 1;

  ** new plants five years later;
  if emp = . then do;
      demp = empforward;
      emp2 = empforward;
      newplant = 1;
      firmid = firmidforward;
      dind2 = dind4;
  ** firmid of entrants is id of firm that owns the plant five years later;
  ** some of these plants will be owned by firms that exist at time t -- others will be firms that are brand new at t+1 (five years later;
  end;

  ** plants that exit five years later *********;
  if empforward = . then do;
      demp = - emp;
      exitplant = 1;
  * change in employment is minus employment at time t *****;
  end;


  if demp = . then delete;
  if year = 1983 or year = 1988 or year = 1993 or year = 1998 or year = 2003 or year = 2008;
run;

data oneb2;
  set onec;
  if changeowner = 1;
  demp = - emp;  * change in employment is minus employment at time t;
  exitplant = 1;
  empforward = .;
  * surviving establishments that change ownership counted as exiter -- firmid is firm that owns plant at time t;
  * these are will also be considered new plants at t+1;
run;

data onec2;
  set onec;
  if changeowner = 1;
  demp = empforward;
  firmid = firmidforward;
  emp = .;
  newplant = 1;
  exitplant = 0;
run;

data oned2;
  set onec;
  if changeowner = 1 then delete;
run;

data onec (drop=firmidforward);
  set oned2 oneb2 onec2;
  if emp = . then emp = 0;
  if empforward = . then empforward = 0;
run;  * this now has stacked dataset including new plants in t+1 and surviving plants that switched ownership;

** end of stacked dataset *****************************************************************************************;

** now total employment by industry based on emp2 *********************************************************;
proc sort data=onec; by year dind2;
run;

proc means data=onec noprint;
  var emp2;
  by year dind2;
output out=one2 sum=emp2ind;
run;  *total employment based on emp2;

data onec;
*  (keep=year firmid demp demporig emp empforward);
  merge onec one2 empind; by year dind2;
  demporig = demp;
  share_plant = emp2/emp2ind;
  share_industry = empind/empyear;
  demp = demp - share_plant*(dempind - share_industry*dempyear);
*  demp = demporig;
  * remove this last part if we want adjusted change in employment;
run;

** one has change in employment adjusted by industry and annual employment by plant **************************************;

** aggregate to firm level ************************************************;
proc sort data=onec; by year firmid;
run;

proc means data=onec noprint; by year firmid;
  var emp demp demporig empforward;
  output out=two sum=;
run;

data two;
  merge two d.oneid; by year firmid;
  if demp = . then delete;
run;
* demp is total ADJUSTED change in employment among establishments owned by firm including entrants owned five years later;
* emp is total employment of firm at time t;
* empforward is total employment of firm at time t + 1;
* exit is indicator variable for exiting firm;
* new is indicator variable for new firm at END of period;
** end of aggregation to firm *********************************************;

** two_change two_entry and two_exit *****************************************;

data two_change (keep = year firmid dempsh demp demporig);
  set two;
  if exit = 0 and new = 0;  * restrict to incumbent firms;
  if emp = . then delete;
  avgemp = (empforward + emp)/2;
  if avgemp = . then delete;
  dempsh = demp/avgemp;
  * change in employment as fraction of average employment -- this is what we plot on x-axis;
run;
** two_change has change in employment over five years ************************;

** entry and exit *************************************************************;
data two_exit (keep=year firmid demp dempsh demporig);
  set two;
  if exit = 1;
  dempsh =  - 2;
run;

data two_entry (keep = year firmid demp dempsh demporig);
  set two;
  if new = 1;
  dempsh = 2;
  * year refers to entry year - 5;
run;

* dempsh is positive for entrants and growing incumbents;
* dempsh negative for exiters and incumbents that shrink;
** two_change (incumbents), two_entry, and two_exit are used to calculate JC and JD *******************;

** aggregate changes and entry and exit sample ***********************************;
data twochange_pos (keep=year firmid demp dempsh dempsh2 );
  set two_change two_entry;
  if demp > 0;
  if year > 2008 then delete;  * 2008 is last year with exit over next five years;
  if year < 1983 then delete;  * 1983 is first year with entry over next five years;
  dempsh2 = dempsh;
run;

data twochange_neg (keep=year firmid demp dempsh dempsh2 );
  set two_change two_exit;
  if demp < 0;  * only negative job creation or exit ;
  if year > 2008 then delete;  * 2008 is last year with exit over next five years;
  if year < 1983 then delete;  * 1976 is first year with entry over next five years;
  dempsh2 = -1* dempsh;  * make change positive, including exiting firms;
  demp = demp * -1;  * make job losses positive;
run;  * change back to negative;

** twochange_pos and twochange_neg are samples of job creation and destruction **********;

** total job creation and destruction ************;
proc sort data=twochange_pos; by year;
run;

proc means noprint data=twochange_pos;
  by year;
  var demp;
output out=jc sum=jc;
run;

proc sort data=two_entry; by year;
run;

proc means noprint data=two_entry;
  by year;
  var demp;
output out=entry sum=jc_entry;
run;

data two_small;
  set twochange_pos;
  if demp > 0;
  if dempsh2 < 1;
run;

proc sort data=two_small;
  by year;
run;

proc means data=two_small noprint;
  var demp;
  by year;
output out=two_small sum=jc_small;
run;

proc sort data=twochange_neg; by year;
run;

proc means noprint data=twochange_neg;
  by year;
  var demp;
output out=jd sum=jd;
run;

proc sort data=two_exit; by year;
run;

proc means noprint data=two_exit; by year;
  var demp;
output out=exit sum=jd_exit;
run;

data jc (keep = year jc jcrate jc_entry jc_small);
  merge jc entry two_small empyear;  * empyear has total employment in the two years;
  by year;
  jcrate = jc/((empyear + empyearforward)/2);
  jc_entry = jc_entry/jc;
  jc_small = jc_small/jc;
run;

data jd (keep = year jd jdrate jd_exit);
  merge jd exit empyear;
  by year;
  jdrate = jd/((empyear + empyearforward)/2);
  jd_exit = jd_exit/jd;
run;

data jcjd (drop=year2);
  merge jc jd; by year;
  sample = &i;
  replicate = &j;
  year2 = .;
  if year = 1983 or year = 1988 then year2 = 1988;
  if year = 1993 or year = 1998 then year2 = 1998;
  if year = 2003 or year = 2008 then year2 = 2008;
  if year2 = . then delete;
  year = year2;
run;

proc means data=jcjd noprint;
  by year;
  var jdrate jd_exit jcrate jc_entry jc_small sample replicate;
output out=jcjd mean=;

proc sort data=datatoappend; by year;
proc sort data=jcjd; by year;

data datatoappend (drop=_type_ _freq_);
  merge datatoappend jcjd; by year;
run;

data d.big;
  set d.big datatoappend;
run;

** end total ** adjusted ** job creation and job desruction ***********;


%end;
%end;
%mend sample;

%sample;

proc means data=d.big;

proc corr data=d.big noprog out=outcorr;
  nomiss
  cov;
var ;
run;

* end replicate3.sas **************************;
