%How Destructive is Innovation?
%Daniel Garcia-Macia, Chang-Tai Hsieh & Pete Klenow.
%April 2019

%This function computes the difference between data and model moments,
%given a fixed set of parameters.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [error,param_grid,delta_o,psi,exit_age5_grid,mshare_age5_grid,...
    aver_size_age5,aver_size_model_grid,min_size_grid,...
    creat_dest_grid,exit_size2_level_grid,std_logsize_grid,...
    growth_halt_grid,variety_vec_corrected_store,contrib_growth_age_grid,JC_age_corrected_grid,JD_age_corrected_grid,exit_size500_level_grid,psi_mean]...
    =error_fun(params,sigma,max_age,repetitions,gY,qualpowerstore_vec_guess,model,psi,delta_o,data_mean_size_v2,iterations,...
    data_DHS,data_mshare,data_creat_dest,gN,data_std_logsize,robustness,data_size_age,data_exit_size_2,ub,lb,jacobian,sample)

%check whether parameters are within bounds
if jacobian==0
    outbounds=sum(sum((params>ub')+(params<lb')))>0;
else
    outbounds=0;
end

%recover relevant parameters
if jacobian==0
    param_grid=[1-params(1); params(1:2); 0; params(3); 1; 1; params(4); 1];
    if robustness==1 || robustness==2
        param_grid=[1-params(1); params(1); 0; params(2); params(3); 1; 1; params(4); 1];
    elseif robustness==3 || robustness==4 || robustness>=6
        param_grid=[1-params(1); params(1); 0; params(2:3); 1; 1; params(4); 1];
    elseif robustness==5
        param_grid=[1-params(1); params(1:2); 0; params(3); 1; params(5); params(4); 1];
    end
    if sample>=10
        param_grid=[1-params(1); params(1); 0; params(2:3); 1; 1; params(4); params(5)];
    end
else
    param_grid=params;
end
if model==1 || model==4
    param_grid=[params(1:2); 0; 0; params(3); 1; 1; params(4); 1];
end

%calculate average geometric quality step size s_q consistent with
%parameters and TFP growth (see TFP growth formula in the paper)
if model==5
    sq_grid = (((1+gY-gN).^(sigma-1)+delta_o*(psi-param_grid(8,:))-param_grid(3,:).*param_grid(8,:)-param_grid(4,:).*param_grid(8,:)-1+param_grid(5,:)+(1-param_grid(5,:)).*(param_grid(1,:)+param_grid(2,:).*param_grid(7,:)))./...
        ((param_grid(5,:)+(1-param_grid(5,:)).*param_grid(1,:))+param_grid(7,:).*param_grid(2,:).*(1-param_grid(5,:)))).^(1/(sigma-1));
else
    sq_grid = (((1+gY).^(sigma-1)+delta_o*(psi-param_grid(8,:))-param_grid(3,:).*param_grid(8,:)-param_grid(4,:).*param_grid(8,:)-1+param_grid(5,:)+(1-param_grid(5,:)).*(param_grid(1,:)+param_grid(2,:).*param_grid(7,:)))./...
        ((param_grid(5,:)+(1-param_grid(5,:)).*param_grid(1,:))+param_grid(7,:).*param_grid(2,:).*(1-param_grid(5,:)))).^(1/(sigma-1));
end
param_grid(6)=sq_grid;

theta=(1-sigma)*sq_grid^(sigma-1)/(param_grid(9,:)^(sigma-1)-sq_grid^(sigma-1)); %Pareto shape parameter consistent with parameters and TFP growth

if  theta<2*(sigma-1)+0.2 && model==5 %infinite variance
    outbounds=3;
end

if  outbounds>0
    error=3*outbounds; %output high error and search for new parameters
else
    %Initiate variables to store simulation moments for every iteration in
    %the for loop:
    mshare_age5_grid=zeros(2,iterations); %employment share of young and old firms
    aver_size_age5=zeros(2,iterations);  %size by age for young and old firms
    exit_size2_level_grid=zeros(2,iterations); %exit above and below mean size
    creat_dest_grid=zeros(2,iterations); %aggregate JD and JC
    exit_age5_grid=zeros(2,iterations); %exit by age for young and old firms
    aver_size_model_grid=zeros(1,iterations); %mean size overall
    std_logsize_grid=zeros(1,iterations); %std of log size for all firms
    growth_halt_grid=zeros(82,iterations); %JD and JC by growth (DHS measure)
    min_size_grid=zeros(1,iterations); %minimum firm size
    OH_varieties_killed=[]; %vector with quality of varieties killed by OH costs
    variety_vec_corrected_store=[]; %vector with number of varieties
    contrib_growth_age_grid=zeros(max_age,iterations); %contribution to TFP growth by age
    JC_age_corrected_grid=zeros(max_age,iterations); %contribution to JC by age
    JD_age_corrected_grid=zeros(max_age,iterations); %contribution to JD by age
    exit_size500_level_grid=zeros(8,iterations); %exit by size, bundling at 500+ employees
    
    rng('default') %fix random number generator
    if jacobian>1
        rng(jacobian) %draws for Monte Carlo simulation
    end
    for i=1:iterations %Compute moments given a fixed set of parameters.
        %The quality distribution is updated in every iteration, everything
        %else is fixed.
        tic
        [mshare_age5_grid(:,i),aver_size_age5(:,i),...
            qualpowerstore_vec,variety_vec_corrected,size_vec,...
            growth_halt_grid(:,i),OH_killed_ent,OH_killed_inc,...
            exit_age5_grid(:,i),exit_size2_level_grid(:,i),creat_dest_grid(:,i),...
            aver_size_model_grid(:,i),std_logsize_grid(:,i),...
            delta_i,contrib_growth_age_grid(:,i),...
            JC_age_corrected_grid(:,i),JD_age_corrected_grid(:,i),exit_size500_level_grid(:,i),psi_mean]...
            =moments_fun(sigma,param_grid,max_age,repetitions,qualpowerstore_vec_guess,model,psi,delta_o,data_mean_size_v2,robustness);
        toc    
        
        min_size_grid(i)=data_mean_size_v2*min(size_vec)/aver_size_model_grid(i); %rescale min size to average size in the data
                
        %store vector with num. of varieties per firm:
        if sample>7
            variety_vec_corrected_store=[1 2 3 4 5]; %placeholder to avoid excessive memory use
        else
            variety_vec_corrected_store=[variety_vec_corrected_store;variety_vec_corrected];
        end
        %update quality distribution for next iteration:
        qualpowerstore_vec_guess=qualpowerstore_vec;
        %force mean quality to be one to avoid small-sample deviations from
        %stationarity:
        qualpowerstore_vec_guess=qualpowerstore_vec_guess/mean(qualpowerstore_vec_guess);
        %Compute fraction of varieties killed by OH costs:
        OH_varieties_killed=[OH_varieties_killed (length(OH_killed_ent)+length(OH_killed_inc))/length(qualpowerstore_vec)];
        %update delta_o to be consistent with fraction of varieties killed
        %by OH costs:
        delta_o=0.6*delta_o+0.4*mean(OH_varieties_killed);
        %update psi to target a minimum employment of 1
        psi=max(0,min(max(psi,5e-5)*(1-0.3*(min_size_grid(i)-1)),(param_grid(8))^(sigma-1)*param_grid(7))) %impose a lower bound so that contribution of new varieties is positive
        if robustness==5 %in targeted entrants model, delta_i may need to be updated so that the total CD rate is <=1
            param_grid(1)=delta_i;
            sq_grid = (((1+gY-gN).^(sigma-1)+delta_o*(psi-param_grid(8,:))-param_grid(3,:).*param_grid(8,:)-param_grid(4,:).*param_grid(8,:)-1+param_grid(5,:)+(1-param_grid(5,:)).*(param_grid(1,:)+param_grid(2,:).*param_grid(7,:)))./...
                ((param_grid(5,:)+(1-param_grid(5,:)).*param_grid(1,:))+param_grid(7,:).*param_grid(2,:).*(1-param_grid(5,:)))).^(1/(sigma-1));
            param_grid(6)=sq_grid;
        end
    end
    
    %compute error in target moments:
    if robustness~=8
        cutoff_smallJC=61;
    else
        cutoff_smallJC=54;
    end
    
    error_all=[mean(abs(mean(data_mean_size_v2*aver_size_age5(:,5:end)./repmat(aver_size_model_grid(:,5:end),2,1),2)./data_size_age-1));...
        mean(mshare_age5_grid(1,5:end),2)/data_mshare(1)-1;...
        mean(creat_dest_grid(:,5:end),2)./data_creat_dest-1;...
        mean(std_logsize_grid(:,5:end))/data_std_logsize(2)-1;delta_o/mean(OH_varieties_killed)-1;...
        mean(sum(growth_halt_grid(42:cutoff_smallJC,5:end))./sum(growth_halt_grid(42:end,5:end)))/(sum(data_DHS(42:cutoff_smallJC))./sum(data_DHS(42:end)))-1;...
        mean(min_size_grid(:,5:end))-1;...
        mean(abs(mean(exit_size2_level_grid(:,5:end),2)./data_exit_size_2-1))];
    
    %display errors:
    {'size_age','entrants','JC','JD','sdev','OH','JC<1','min','exit_size'}
    error_all'
    
    %compute distance measure based on root mean squared error of relevant moments:
    error=sqrt(mean(error_all([1:5 7 end]).^2))
    
end