%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%How Destructive is Innovation?
%Daniel Garcia-Macia, Chang-Tai Hsieh and Pete Klenow
%April 2019

%This code loads the data and the simulation results in order to generate
%the plots included in the paper. It also generates additional plots.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all; clear all; clc;

%grey colors
grey=0.55*[1 1 1];
palegrey=0.75*[1 1 1];

Excel = actxserver('Excel.Application');
Excel.DisplayAlerts = 0;  

%Load data: Job Creation (JC) and Job Destruction (JD)
JDJC_88_data=xlsread('sim_results.xls',2,'d31:d32'); %Data in 1988
JDJChist_88_data=xlsread('sim_results.xls',2,'d40:d121');
JDJCsmall_88_data=[xlsread('sim_results.xls',2,'d30') xlsread('sim_results.xls',2,'d182')/100];
JDJC_98_data=xlsread('sim_results.xls',3,'d31:d32'); %Data in 1998
JDJChist_98_data=xlsread('sim_results.xls',3,'d40:d121');
JDJCsmall_98_data=[xlsread('sim_results.xls',3,'d30') xlsread('sim_results.xls',3,'d182')/100];
JDJC_08_data=xlsread('sim_results.xls',4,'d31:d32'); %Data in 2008
JDJChist_08_data=xlsread('sim_results.xls',4,'d40:d121');
JDJCsmall_08_data=[xlsread('sim_results.xls',4,'d30') xlsread('sim_results.xls',4,'d182')/100];
JDJC_08_1=xlsread('sim_results.xls',4,'e31:e32'); %Model in 2008
JDJChist_08_1=xlsread('sim_results.xls',4,'e40:e121');

%Express in absolute job flows:
JDJCrate_88_data=[JDJC_88_data(2)*ones(length(JDJChist_88_data)/2,1)/sum(JDJChist_88_data(42:end));JDJC_88_data(1)*ones(length(JDJChist_88_data)/2,1)/sum(JDJChist_88_data(1:41))].*JDJChist_88_data;
JDJCrate_08_data=[JDJC_08_data(2)*ones(length(JDJChist_08_data)/2,1)/sum(JDJChist_08_data(42:end));JDJC_08_data(1)*ones(length(JDJChist_08_data)/2,1)/sum(JDJChist_08_data(1:41))].*JDJChist_08_data;
JDJCrate_08_1=[JDJC_08_1(2)*ones(length(JDJChist_08_1)/2,1)/sum(JDJChist_08_1(42:end));JDJC_08_1(1)*ones(length(JDJChist_08_1)/2,1)/sum(JDJChist_08_1(1:41))].*JDJChist_08_1;

%Load data: entry share
entr_sh_88_data=xlsread('sim_results.xls',2,'d24');
entr_sh_88_1=xlsread('sim_results.xls',2,'e24');
entr_sh_98_data=xlsread('sim_results.xls',3,'d24');
entr_sh_98_1=xlsread('sim_results.xls',3,'e24');
entr_sh_08_data=xlsread('sim_results.xls',4,'d24');
entr_sh_08_1=xlsread('sim_results.xls',4,'e24');

% Load data: size by age
size_age_88_data=xlsread('sim_results.xls',2,'d25:d26');
size_age_88_1=xlsread('sim_results.xls',2,'e25:e26');
size_age_98_data=xlsread('sim_results.xls',3,'d25:d26');
size_age_98_1=xlsread('sim_results.xls',3,'e25:e26');
size_age_08_data=xlsread('sim_results.xls',4,'d25:d26');
size_age_08_1=xlsread('sim_results.xls',4,'e25:e26');

% %Load data: exit by size
exit_size_88_data=xlsread('sim_results.xls',2,'d33:d34');
exit_size_98_data=xlsread('sim_results.xls',3,'d33:d34');
exit_size_08_data=xlsread('sim_results.xls',4,'d33:d34');

%%
% Plot JC and JD 
figure(4)
bar([1 2]-0.125,100*JDJC_88_data([2 1]),0.08,'FaceColor','k','EdgeColor','k')
hold on
bar([1 2],100*JDJC_98_data([2 1]),0.08,'FaceColor',grey,'EdgeColor',grey)
bar([1 2]+0.125,100*JDJC_08_data([2 1]),0.08,'FaceColor',palegrey,'EdgeColor',palegrey)
get(gca, 'XTick');
set(gca,'FontSize',22)
set(gca, 'XTickLabel', {'','destruction','', 'creation'})
ylabel('job creation/destruction (%)','FontSize',22)
xlim([0.5 2.5])
ylim([0 45])
set(gca,'FontSize',22)
legend('1983-1993','1993-2003','2003-2013','location','northwest')
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/JDJC_all_data.jpg')


%Plots for the entrants' share
figure(5)
bar(1,100*entr_sh_88_data,0.15,'FaceColor','k','EdgeColor','k')
hold on
bar(1.5,100*entr_sh_98_data,0.15,'FaceColor',grey,'EdgeColor',grey)
bar(2,100*entr_sh_08_data,0.15,'FaceColor',palegrey,'EdgeColor',palegrey)
get(gca, 'XTick');
set(gca,'FontSize',22)
set(gca, 'XTickLabel', {'','Data 1988','Data 1998', 'Data 2008'})
ylabel('employment share of entrants (%)','FontSize',22)
xlim([0.5 2.5])
ylim([0 25])
set(gca,'FontSize',22)
legend('1983-1993','1993-2003','2003-2013')
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/entrant_share_data.jpg')

% Plot JC and JD histograms
figure(6)
bar(-1.975:0.05:1.975,100*JDJCrate_88_data(2:end-1),1,'FaceColor','k','EdgeColor','k')
hold on
bar(-1.975:0.05:1.975,100*JDJCrate_08_data(2:end-1),0.5,'FaceColor',palegrey,'EdgeColor',palegrey)
linex=[0 0];
liney=[0 4];
plot(linex,liney,'k--');
xlabel('growth rate of employment','FontSize',22)
ylabel('job creation/destruction (%)','FontSize',22)
xlim([-2 2])
set(gca,'FontSize',22)
legend('1983-1993','2003-2013','location','northwest')
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/hist_jobcreat_all_data.jpg')

% Plot small JC and JD shares
figure(7)
bar([1 2]-0.125,100*JDJCsmall_88_data,0.08,'FaceColor','k','EdgeColor','k')
hold on
bar([1 2],100*JDJCsmall_98_data,0.08,'FaceColor',grey,'EdgeColor',grey)
bar([1 2]+0.125,100*JDJCsmall_08_data,0.08,'FaceColor',palegrey,'EdgeColor',palegrey)
get(gca, 'XTick');
set(gca,'FontSize',22)
set(gca, 'XTickLabel', {'','job creation','', 'job destruction'})
ylabel('share small flows (%)','FontSize',22)
xlim([0.5 2.5])
ylim([0 40])
set(gca,'FontSize',22)
legend('1983-1993','1993-2003','2003-2013','location','northeast')
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/JCJDsmall_data.jpg')

%Plots for size by age
figure(8)
bar([1 2]-0.125,size_age_88_data,0.08,'FaceColor','k','EdgeColor','k')
hold on
bar([1 2],size_age_98_data,0.08,'FaceColor',grey,'EdgeColor',grey)
bar([1 2]+0.125,size_age_08_data,0.08,'FaceColor',palegrey,'EdgeColor',palegrey)
get(gca, 'XTick');
set(gca,'FontSize',22)
set(gca, 'XTickLabel', {'','age < 5', '','age 5+'})
ylabel('employees','FontSize',22)
xlim([0.5 2.5])
ylim([0 35])
set(gca,'FontSize',22)
legend('1983-1993','1993-2003','2003-2013','location','northwest')
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/size_age_all_data.jpg')

%Plots for exit by size
figure(9)
bar([1 2]-0.125,100*exit_size_88_data,0.08,'FaceColor','k','EdgeColor','k')
hold on
bar([1 2],100*exit_size_98_data,0.08,'FaceColor',grey,'EdgeColor',grey)
bar([1 2]+0.125,100*exit_size_08_data,0.08,'FaceColor',palegrey,'EdgeColor',palegrey)
get(gca, 'XTick');
set(gca,'FontSize',22)
set(gca, 'XTickLabel', {'','small', '','large'})
ylabel('annual exit rate (%)','FontSize',22)
xlim([0.5 2.5])
ylim([0 10])
set(gca,'FontSize',22)
legend('1983-1993','1993-2003','2003-2013')
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/exit_size_all_data.jpg')

% Plot JC and JD histograms in model
figure(12)
bar(-1.975:0.05:1.975,100*JDJCrate_08_1(2:end-1),0.5,'FaceColor','k','EdgeColor','k')
hold on
linex=[0 0];
liney=[0 4];
plot(linex,liney,'k--');
xlabel('growth rate of employment','FontSize',22)
ylabel('job creation/destruction (%)','FontSize',22)
xlim([-2 2])
set(gca,'FontSize',22)
% legend('Data 1981','Own inn.')
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/hist_jobcreat_model.jpg')

%% Plots for polar models vs data

%Polar Model 1
load polar1_moments_data_plot
JDJChist_polar_1=mean(growth_halt_grid,2);
JDJC_polar_1=mean(creat_dest_grid,2);
JDJCrate_polar_1=[JDJC_polar_1(2)*ones(length(JDJChist_polar_1)/2,1);JDJC_polar_1(1)*ones(length(JDJChist_polar_1)/2,1)].*JDJChist_polar_1;
exit_age_polar_1=mean(exit_age5_grid,2);
size_age_polar_1=mean(size_age5_grid,2);

param_grid=[(1-0.283)*(1-.779) 0.283*(1-.779)  0 0 0 1 1 [1 1]]; %use same parameters as in the simulation

%Plot for Polar Model 4: KK with sigma=4
load polar_KK3

figure(1)
bar(-1.975:0.05:1.975,JDJCrate_KK3(2:end-1),0.5,'FaceColor',grey,'EdgeColor',grey)
hold on
bar(-1.975:0.05:1.975,JDJCrate_polar_1(2:end-1),0.5,'FaceColor','k','EdgeColor','k')
linex=[0 0];
liney=[0 10];
plot(linex,liney,'k--');
xlabel('growth rate of employment','FontSize',22)
ylabel('job creation/destruction (%)','FontSize',22)
xlim([-2 2])
set(gca,'FontSize',22)
% legend('Data 1981','KK sigma=4',2)
legend('\sigma=4','\sigma=1')
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/hist_jobcreat_KK.jpg')


figure(2)
plot(1:8,100*exit_size_KK3(1:end-2),'k--','LineWidth',2)
hold on
plot(1:8,[NaN 100/5*((1-param_grid(1))*(param_grid(2)+param_grid(1))).^([10 15 35 75 175 375 1000]/size_age_08_data(1))],'k','LineWidth',2)
get(gca, 'XTick');
set(gca,'FontSize',10)
set(gca, 'XTickLabel', {'0-5', '5-10', '10-20', '20-50', '50-100', '100-250','250-500', '500+'})
ylabel('annual exit rate (%)','FontSize',22)
xlabel('employees','FontSize',22)
ylim([0 5])
set(gca,'FontSize',22)
legend('\sigma=4','\sigma=1')
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/exit_size_KK.jpg')

%Polar 3

load polar3_moments_data_plot

figure(3)
% bar(-1.975:0.05:1.975,JDJCrate_88_data(2:end-1),1,'FaceColor','k','EdgeColor','k')
hold on
bar(-1.975:0.05:1.975,mean(growth_haltabs_grid(2:end-1,:),2),0.5,'FaceColor','k','EdgeColor','k')
linex=[0 0];
liney=[0 4];
plot(linex,liney,'k--');
xlabel('growth rate of employment','FontSize',22)
ylabel('job creation/destruction (%)','FontSize',22)
xlim([-2 2])
set(gca,'FontSize',22)
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 12 5.5]*2.77)
saveas(gcf,'figures/hist_jobcreat_polar_3.jpg')
